@@ -16,7 +16,7 @@ use GD::Polygon;
 
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD);
 
-$VERSION = '2.67';
+$VERSION = '2.72';
 our $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -1305,8 +1305,13 @@ This method is only available with libgd >= 2.1.0
 
 Creates a new palette image from a truecolor image.
 
-  samplefactor	The quantization precision between 1 (highest quality) and 10 (fastest).
-  maxcolor	The number of desired palette entries.
+=over 4
+
+=item samplefactor	The quantization precision between 1 (highest quality) and 10 (fastest).
+
+=item maxcolor	The number of desired palette entries.
+
+=back
 
 This is the same as createPaletteFromTrueColor with the
 quantization method GD_QUANT_NEUQUANT. This does not support dithering.
@@ -1432,7 +1437,7 @@ $add: -255..255
 =item B<$ok = $image-E<gt>contrast($contrast)>
 
 $contrast: a double value. The contrast adjustment value. Negative
-values increase, postive values decrease the contrast. The larger
+values increase, positive values decrease the contrast. The larger
 the absolute value, the stronger the effect.
 
 =item B<$ok = $image-E<gt>color($red,$green,$blue,$alpha)>
@@ -1487,7 +1492,7 @@ installed with GD (see the bdf_scripts directory if it wasn't).  The
 format happens to be identical to the old-style MSDOS bitmap ".fnt"
 files, so you can use one of those directly if you happen to have one.
 
-For writing proportional scaleable fonts, GD offers the stringFT()
+For writing proportional scalable fonts, GD offers the stringFT()
 method, which allows you to load and render any TrueType font on your
 system.
 
